@@ -3,7 +3,7 @@ package Alzabo::Exceptions;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/;
 
 my %e;
 
@@ -80,6 +80,21 @@ use Exception::Class (%e);
 
 Alzabo::Exception->Trace(1);
 
+package Alzabo::Exception::Driver;
+
+sub full_message
+{
+    my $self = shift;
+
+    my $msg = $self->error;
+    $msg .= "\nSQL: " . $self->sql if $self->sql;
+
+    my @bind = map { defined $_ ? $_ : '<undef>' } @{ $self->bind };
+    $msg .= "\nBIND: @bind" if @bind;
+
+    return $msg;
+}
+
 1;
 
 =head1 NAME
